from enum import Enum

class Video_category(str, Enum):
    Adult = "Adult",
    AnimalsBirds = "Animals Birds",
    AnimalsCats = "Animals Cats",
    AnimalsDogs = "Animals Dogs",
    Animated = "Animated",
    Anime = "Anime",
    Gaming = "Gaming",
    Graphics = "Graphics",
    Illustrations = "Illustrations",
    Movie = "Movie",
    Other = "Other",
    OtherPeople = "Other People",
    SportsBasketball = "Sports Basketball",
    SportsHockey = "Sports Hockey",
    SportsOther = "Sports Other",
    SportsRacing = "Sports Racing",
    SportsSoccer = "Sports Soccer",
    SportsTennis = "Sports Tennis",
    Unknown = "unknown",

