from enum import Enum

class EdgeReplicationRegions(str, Enum):
    DE = "DE",
    UK = "UK",
    SE = "SE",
    CZ = "CZ",
    ES = "ES",
    NY = "NY",
    LA = "LA",
    WA = "WA",
    MI = "MI",
    SG = "SG",
    HK = "HK",
    JP = "JP",
    SYD = "SYD",
    BR = "BR",
    JH = "JH",

