from enum import Enum

class Properties_crop_gravity(str, Enum):
    Center = "center",
    Forget = "forget",
    East = "east",
    North = "north",
    South = "south",
    West = "west",
    Northeast = "northeast",
    Northwest = "northwest",
    Southeast = "southeast",
    Southwest = "southwest",

